@@ -116,6 +116,10 @@ class AutoDocProcessor(BlockProcessor):
 
         block, the_rest = self.detab(block)
 
+        if not block and blocks and blocks[0].startswith(("    handler:", "    options:")):
+            # YAML options were separated from the `:::` line by a blank line.
+            block = blocks.pop(0)
+
         if match:
             identifier = match["name"]
             heading_level = match["heading"].count("#")
@@ -257,7 +261,7 @@ class _TocLabelsTreeProcessor(Treeprocessor):
         for token in tokens:
             if (label := token.get("data-toc-label")) and token["name"] != label:
                 token["name"] = label
-                self._override_toc_labels(token["children"])
+            self._override_toc_labels(token["children"])
 
 
 class MkdocstringsExtension(Extension):
