@@ -172,6 +172,11 @@ def test_use_options_yaml_key(ext_markdown: Markdown) -> None:
     assert "h1" not in ext_markdown.convert("::: tests.fixtures.headings\n    options:\n      heading_level: 2")
 
 
+def test_use_yaml_options_after_blank_line(ext_markdown: Markdown) -> None:
+    """Check that YAML options are detected even after a blank line."""
+    assert "h1" not in ext_markdown.convert("::: tests.fixtures.headings\n\n    options:\n      heading_level: 2")
+
+
 @pytest.mark.parametrize("ext_markdown", [{"markdown_extensions": [{"admonition": {}}]}], indirect=["ext_markdown"])
 def test_removing_duplicated_headings(ext_markdown: Markdown) -> None:
     """Assert duplicated headings are removed from the output."""
